# Botoolkit

Семейство инструментов предназначенное для сокращения рутинных действий 
разработчиков проектов web_bb и организации работы со сторонними сервисами.

Набор содержит следующие инструменты:
* boconf
* bodatabaser
* barsdock
* bogit
* boguide
* boip
* bojenkins
* bojira
* bopostgres
* boregistry
* botelegram
* botoolkit
* bowebbb 

Данные инструменты нацелены на объединение существующих решений с создание новых
в едином проекте в качестве консольных утилит для повышения удобства работы с 
проектом и сокращения издержек выполнение рутинных задач. Более подробно с 
инструментом можно ознакомиться в [Confluence](https://conf.bars.group/display/BONLINE/BO+Toolkit).

## Версионирование

В проекте используется Семантическое версионирование. Со спецификацией можно ознакомиться по ссылке 
https://semver.org/lang/ru/